#include <tclap/CmdLine.h>
#include <Kafka_Provider_Configurator.h>

using namespace inaf::oasbo::Providers;

KafkaProviderConfigurator::KafkaProviderConfigurator(){
	setBrokerIP("127.0.0.1");
	setBrokerPort(9003);
	setTopic("DAQ_topic");
}


KafkaProviderConfigurator::KafkaProviderConfigurator(int argc, char ** argv){
	try {
		TCLAP::CmdLine cmd("Usage Description WIP", ' ', "1");
		cmd.ignoreUnmatched(true);
		TCLAP::ValueArg<std::string> brokerIP("","brokerIP","kafka broker IP address",false,"127.0.0.1","X.X.X.X");
		cmd.add( brokerIP );
		TCLAP::ValueArg<std::string> brokerPort("","brokerPort","listening port of the kafka broker",false,"9092","int");
		cmd.add( brokerPort );
		TCLAP::ValueArg<std::string> defTopic("","topic","kafka producer topic",false,"DAQ_topic","string");
		cmd.add( defTopic );

		cmd.parse( argc, argv );

		setBrokerIP(brokerIP.getValue());
		setBrokerPort(std::stoi(brokerPort.getValue()));
		setTopic(defTopic.getValue());
	}catch (TCLAP::ArgException &e){  // catch any exceptions
		std::cerr << "error: " << e.error() << " for arg " << e.argId() << std::endl;
		exit(EXIT_FAILURE);
	}
}

BaseProvider * KafkaProviderConfigurator::createProvider(){
	return new KafkaProvider(getBrokerIP(),getBrokerPort(), getTopic());
}

KafkaProvider * KafkaProviderConfigurator::createKafkaProvider(){
	return new KafkaProvider(getBrokerIP(),getBrokerPort(), getTopic());
}


